@@ -1,5 +1,5 @@
 /****************************************************************************
- * Copyright 2018-2023,2025 Thomas E. Dickey                                *
+ * Copyright 2018-2024,2025 Thomas E. Dickey                                *
  * Copyright 2008-2016,2017 Free Software Foundation, Inc.                  *
  *                                                                          *
  * Permission is hereby granted, free of charge, to any person obtaining a  *
@@ -39,30 +39,28 @@
 
 #include <curses.priv.h>
 
-#ifdef _NC_WINDOWS
-
 #define CUR TerminalType(my_term).
 
-MODULE_ID("$Id: win32_driver.c,v 1.16 2025/12/20 17:28:44 tom Exp $")
+MODULE_ID("$Id: win32_driver.c,v 1.18 2025/12/27 20:52:25 tom Exp $")
 
 #define WINMAGIC NCDRV_MAGIC(NCDRV_WINCONSOLE)
 #define EXP_OPTIMIZE 0
 
-static bool console_initialized = FALSE;
-
 #define AssertTCB() assert(TCB != NULL && (TCB->magic == WINMAGIC))
-#define validateConsoleHandle() (AssertTCB() , console_initialized ||\
-                                 (console_initialized=\
-                                  _nc_console_checkinit(TRUE,FALSE)))
+#define validateConsoleHandle() (AssertTCB(), console_initialized || \
+                                 (console_initialized = \
+                                  _nc_console_checkinit(USE_NAMED_PIPES)))
 #define SetSP() assert(TCB->csp != NULL); sp = TCB->csp; (void) sp
 
 #define AdjustY() (WINCONSOLE.buffered \
                    ? 0 \
                    : (int) WINCONSOLE.SBI.srWindow.Top)
 
-#define RevAttr(attr) (WORD) (((attr) & 0xff00) |   \
-                              ((((attr) & 0x07) << 4) | \
-                               (((attr) & 0x70) >> 4)))
+#define RevAttr(attr) (WORD) (((attr) & 0xff00) | \
+		      ((((attr) & 0x07) << 4) | \
+		       (((attr) & 0x70) >> 4)))
+
+static bool console_initialized = FALSE;
 
 static WORD
 MapAttr(WORD res, attr_t ch)
@@ -726,7 +724,7 @@ static int
 wcon_sgmode(TERMINAL_CONTROL_BLOCK * TCB, int setFlag, TTY * buf)
 {
     int result = ERR;
-#if USE_WINCONMODE
+
     T((T_CALLED("win32con::wcon_sgmode(TCB=(%p),setFlag=%d,TTY=(%p)"),
        TCB, setFlag, buf));
     if (buf != NULL && validateConsoleHandle()) {
@@ -740,11 +738,6 @@ wcon_sgmode(TERMINAL_CONTROL_BLOCK * TCB, int setFlag, TTY * buf)
 	}
 	result = OK;
     }
-#else
-    (void) TCB;
-    (void) setFlag;
-    (void) buf;
-#endif /* USE_WINCONMODE */
     returnCode(result);
 }
 
@@ -840,7 +833,7 @@ wcon_init(TERMINAL_CONTROL_BLOCK * TCB)
 
     AssertTCB();
 
-    if (!(console_initialized = _nc_console_checkinit(TRUE, FALSE))) {
+    if (!(console_initialized = _nc_console_checkinit(USE_NAMED_PIPES))) {
 	returnVoid;
     }
 
@@ -1214,5 +1207,3 @@ NCURSES_EXPORT_VAR (TERM_DRIVER) _nc_WIN_DRIVER = {
 	wcon_kyExist,		/* kyExist       */
 	wcon_cursorSet		/* cursorSet     */
 };
-
-#endif /* _NC_WINDOWS */
